-- by modelleicher
-- www.ls-modcompany.com
-- https://www.youtube.com/modelleicher

-- 20.07.2018
-- speed of "mouse controlled" objects dependent on RPM 
-- only works with GearboxAddon because you can't manually control RPM otherwise

rpmDependentControls = {};


	
function rpmDependentControls.prerequisitesPresent(specializations)
	return true;
end;

function rpmDependentControls:load(savegame)
	self.movingToolBackup = {rotSpeed = {}, transSpeed = {}, animSpeed = {}}; -- create backup table
end
function rpmDependentControls:postLoad(savegame)
	-- load all movingTools speeds into backup table
	for i = 1, #self.movingTools do
		local tool = self.movingTools[i];
		if tool.rotSpeed ~= nil then
			self.movingToolBackup.rotSpeed[i] = tool.rotSpeed;
		end;
		if tool.transSpeed ~= nil then
			self.movingToolBackup.transSpeed[i] = tool.transSpeed;
		end;
		if tool.animSpeed ~= nil then
			self.movingToolBackup.animSpeed[i] = tool.animSpeed;
		end;				
	end;
	
end


function rpmDependentControls:update(dt)
	if self:getIsActive() then
		local rpmFactor = nil; -- rpm factor stays nil unless vehicle or attacherVehicle has GBAddon installed and active
		if self.mrGbMS ~= nil and self.mrGbMS.IsOn then
			rpmFactor = (self:mrGbMGetCurrentRPM() / self.mrGbMS.CurMaxRpm) * 1.18; -- rpm factor is divided by RPM and multiplied by 1.18 to speed the loaders up just a little
		elseif self.attacherVehicle ~= nil and self.attacherVehicle.mrGbMS ~= nil and self.attacherVehicle.mrGbMS.IsOn then
			rpmFactor = (self.attacherVehicle:mrGbMGetCurrentRPM() / self.attacherVehicle.mrGbMS.CurMaxRpm) * 1.18;
		end;
		
		-- only if RPM Factor is not nil (e.g. gearbox is installed and active) change speed
		if rpmFactor ~= nil then			
			for i = 1, #self.movingTools do
				local tool = self.movingTools[i];
				if tool.rotSpeed ~= nil then
					tool.rotSpeed = self.movingToolBackup.rotSpeed[i] * rpmFactor;
				end;
				if tool.transSpeed ~= nil then
					tool.transSpeed = self.movingToolBackup.transSpeed[i] * rpmFactor;
				end;	
				if tool.animSpeed ~= nil then
					tool.animSpeed = self.movingToolBackup.animSpeed[i] * rpmFactor;
				end;				
			end;
		end;	
	end;
end



function rpmDependentControls:draw()
end;
function rpmDependentControls:delete()

end;
function rpmDependentControls:mouseEvent(posX, posY, isDown, isUp, button)
end;
function rpmDependentControls:keyEvent(unicode, sym, modifier, isDown)
end;

function rpmDependentControls:readStream(streamId, connection)
end;

function rpmDependentControls:writeStream(streamId, connection)
end;



